@@ -16,6 +16,11 @@
 #define DEBUG_USE_EXAMPLE_CONSTANTS 1
 
 #if HAVE_MBEDTLS
+// musl's sched.h includes a prototype for calloc, so we need to make
+// sure it's already been included before we redefine it to something
+// that won't expand to a valid prototype.
+#include <sched.h>
+
 #define malloc(size) _test_malloc(size, __FILE__, __LINE__)
 #define calloc(num, size) _test_calloc(num, size, __FILE__, __LINE__)
 #define free(obj) _test_free(obj, __FILE__, __LINE__)
