@@ -18,7 +18,7 @@ const char help_urlstr[] = "\nUsage: append to end of individual rist:// url(s)
 "    param cname=abcde  arbitrary name for stream for display in logging\n"
 "    param rtt-min=###  minimum expected rtt\n"
 "    param rtt-max=###  maximum expected rtt\n"
-"    param verbose-level=#  Disable -1; Error 3, Warning 4, Notice 5, Info 6, Debug 7, simulation/dry-run 100\n"
+//"    param verbose-level=#  Disable -1; Error 3, Warning 4, Notice 5, Info 6, Debug 7, simulation/dry-run 100\n"
 "    param timing-mode=#  0 = RTP Timestamp (default); 1 = Arrival Time, 2 = RTP/RTCP Timestamp+NTP\n"
 "  Main and Advanced Profiles\n"
 "    param aes-type=#  128 = AES-128, 256 = AES-256 must have passphrase too\n"
@@ -33,16 +33,16 @@ const char help_urlstr[] = "\nUsage: append to end of individual rist:// url(s)
 "    param weight=#  default weight for multi-path load balancing. Use 0 for duplicate paths.\n"
 "    param username=abcde  Username to identify this peer during authentication\n"
 "    param password=abcde  Password corresponding to this peer's Username\n"
-"    param multiplex-mode=#  Controls how rist payload is muxed/demuxed (-1=auto-detect, 0=rist/raw, \n"
-"                      1=vrt_src_port, 2=ipv4)\n"
-//"    param multiplex-filter=#  When using mux-mode=ipv4, this is the string to be used for data filter.\n"
-//"                        It should be written as destination IP:PORT\n"
 "  Advanced Profile\n"
 "    param compression=1|0  enable lz4 levels\n"
 "\n"
 "Usage: append to end of individual udp:// or rtp:// url(s) as ?param1=value1&param2=value2...\n"
 "  param miface=(device)  device name (e.g. eth0) for multicast\n"
 "  param stream-id=#  ID number (arbitrary) for multiplex/demultiplexing steam in peer connector\n"
+"  param multiplex-mode=#  Controls how rist payload is muxed/demuxed\n"
+"                        (-1=auto-detect, 0=rist/raw, 1=vrt_src_port, 2=ipv4)\n"
+//"  param multiplex-filter=#  When using mux-mode=ipv4, this is the string to be used for data filter.\n"
+//"                        It should be written as destination IP:PORT\n"
 //"  param rtp-timestamp=#  carry over the timestamp to/from the rtp header into/from rist (0 or 1)\n"
 //"  param rtp-sequence=#  carry over the sequence number to/from the rtp header into/from rist (0 or 1)\n"
 //"  param rtp-ptype=# override the default RTP PTYPE to this value\n"
